import {
  isSchemaObjectFlat
} from "./chunk-REMT6GKB.js";
import {
  assert
} from "./chunk-M6NJWFDP.js";
import {
  objectMap
} from "./chunk-MLCD7TOL.js";
import {
  valueToInteger
} from "./chunk-QUQRUDWG.js";
import {
  toCamelCase
} from "./chunk-HJ22ULAI.js";

// src/common/schema/args.ts
function parseSchemaArgs(schema, args = process?.argv ?? {}) {
  assert(isSchemaObjectFlat(schema), "schema should be a flat object");
  const alias = {};
  const booleanArgs = [];
  objectMap(schema._object, (key, schema2) => {
    if (schema2._props?.argShort)
      alias[toCamelCase(schema2._props.argShort)] = toCamelCase(key);
    if (schema2.type === "boolean") {
      booleanArgs.push(toCamelCase(key));
    }
  });
  const argList = [...args];
  let arg;
  const names = [];
  const argsObj = {};
  while (arg = argList.shift()) {
    let value;
    if (/^--?/.test(arg)) {
      let key = arg.replace(/^--?/, "");
      if (arg.includes("=")) {
        const [name, valuePart] = key.split("=", 2);
        key = name.trim();
        value = valuePart.trim();
      }
      key = toCamelCase(key);
      key = alias[key] ?? key;
      if (booleanArgs.includes(key)) {
        argsObj[key] = true;
      } else {
        value = value ?? argList.shift() ?? "";
        argsObj[key] = value;
      }
    } else {
      names.push(arg);
    }
  }
  const argsResult = objectMap(schema._object, (key, schema2) => {
    let value = argsObj[toCamelCase(key)];
    if (schema2.type === "number") {
      value = valueToInteger(value);
    }
    return schema2.parse(value);
  });
  return [argsResult, names];
}

export {
  parseSchemaArgs
};
//# sourceMappingURL=chunk-ZXINKU3Z.js.map